<template>
  <div class="app-container">
    <el-tabs v-model="activeName" @tab-click="fetchData">
      <el-tab-pane label="课后点评" name="comment">
        <div style="display: flex; flex-direction: row-reverse">
          <div style="width: 300px">
            <el-input
              placeholder="按课程名称搜索"
              v-model="data.keyword"
              class="input-with-select"
              size="small"
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="fetchData"
              ></el-button>
            </el-input>
          </div>
        </div>
        <div style="height: calc(100vh - 208px)">
          <el-table
            v-loading="listLoading"
            :data="list"
            element-loading-text="Loading"
            fit
            height="100%"
          >
            <el-table-column label="课程名称">
              <template slot-scope="scope">
                <el-link type="primary" :underline="false">{{
                  scope.row.courseName
                }}</el-link>
              </template>
            </el-table-column>
            <el-table-column label="课程时间" width="">
              <template slot-scope="scope">
                {{ scope.row.beginTime }}
              </template>
            </el-table-column>
            <el-table-column label="教师" width="" prop="staffNames">
            </el-table-column>
            <el-table-column label="学员数" width="" prop="playerCount">
            </el-table-column>
            <el-table-column label="已点评数" width="" prop="commentCount">
            </el-table-column>
          </el-table>
        </div>
        <div>
          <el-pagination
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="data.pageIn.index + 1"
            :page-sizes="[10, 20, 30, 40]"
            :page-size="data.pageIn.size"
            layout="total, sizes, prev, pager, next, jumper"
            :total="total"
          >
          </el-pagination>
        </div>
      </el-tab-pane>
      <el-tab-pane label="其他" name="other">
        <div style="display: flex; flex-direction: row-reverse">
          <div style="width: 300px">
            <el-input
              placeholder="按学员名称搜索"
              v-model="data.keyword"
              class="input-with-select"
              size="small"
            >
              <el-button slot="append" icon="el-icon-search" @click="fetchData"></el-button>
            </el-input>
          </div>
        </div>
        <div style="height: calc(100vh - 208px)">
          <el-table
            v-loading="listLoading"
            :data="list"
            element-loading-text="Loading"
            fit
            height="100%"
          >
            <el-table-column label="学员名称">
              <template slot-scope="scope">
                <el-link type="primary" :underline="false">{{
                  scope.row.player.name
                }}</el-link>
              </template>
            </el-table-column>
            <el-table-column label="点评时间" width="" prop="createTime">
            </el-table-column>
          </el-table>
        </div>
        <div>
          <el-pagination
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="data.pageIn.index + 1"
            :page-sizes="[10, 20, 30, 40]"
            :page-size="data.pageIn.size"
            layout="total, sizes, prev, pager, next, jumper"
            :total="total"
          >
          </el-pagination>
        </div>
      </el-tab-pane>
    </el-tabs>
  </div>
</template>

<script>
import { getSessionWithComment, getHomeworkCommentByAuth } from "@/api/comment";

export default {
  filters: {
    statusFilter(status) {
      const statusMap = {
        published: "success",
        draft: "gray",
        deleted: "danger",
      };
      return statusMap[status];
    },
  },
  data() {
    return {
      list: null,
      listLoading: true,
      activeName: "comment",
      total: 0,
      data: {
        staffId: JSON.parse(localStorage.getItem("selectStaff")).id,
        keyword: "",
        pageIn: {
          //可选，如果是分页查询，需要加上。
          index: 0, //必选
          size: 10, //每页的大小。默认20
          sorts: {
            name: "begin_time", //排序字段名称
            direction: "ASC", //排序方向
          },
        },
      },
    };
  },
  created() {
    this.fetchData();
  },
  methods: {
    handleSizeChange(val) {
      this.data.pageIn.size = val;
      this.fetchData("pageIn");
    },
    handleCurrentChange(val) {
      this.data.pageIn.index = val - 1;
      this.fetchData("pageIn");
    },
    fetchData(_val) {
      if (_val !== "pageIn") {
        this.data.pageIn.index = 0;
        this.data.pageIn.size = 10;
      }
      this.listLoading = true;
      if (this.activeName == "comment") {
        this.listLoading = true;
        getSessionWithComment(this.data).then((response) => {
          this.list = response.data.findSessionWithComment.ls;
          this.total = response.data.findSessionWithComment.pageOut.total;
          this.listLoading = false;
        });
      } else if (this.activeName == "other") {
        this.listLoading = true;
        let data = {
          commentTypes: ["DIRECT_COMMENT"],
          staffId: JSON.parse(localStorage.getItem("selectStaff")).id,
          keyword: this.data.keyword,
          pageIn: { ...this.data.pageIn },
        };
        data.pageIn.sorts.name = "createTime";
        data.pageIn.sorts.direction = "DESC";
        getHomeworkCommentByAuth(data).then((response) => {
          this.list = response.data.findHomeworkCommentByAuth.ls;
          this.total = response.data.findHomeworkCommentByAuth.pageOut.total;
          this.listLoading = false;
        });
      }
    },
  },
};
</script>
